==> qcad-3.15.5.3.tgz: lib/qcad/ts/qcadgui_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>カスタム</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>終端</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>エンティティ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>垂直</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>タンジェント</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>中央</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>交点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>基準点</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/ts/qcadgui_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>カスタム</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>終端</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>エンティティ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>垂直</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>タンジェント</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>中央</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>交点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>基準点</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation>無効</translation>
    </message>
</context>
</TS>
